@@ -86,7 +86,7 @@ class SerialPort():
                 except serial.serialutil.SerialException as e:
                     self.exiting = True
                     print("\033[1;33m连接失败，未检测到设备\033[0m")
-                    print('$#&*@{"err_code":102,"err_msg":"未检测到设备","device":"mkpiano","extra":{}}@*&#$')
+                    print('$#&*@{"err_code":102,"err_msg":"发送数据失败，未检测到设备","device":"mkpiano","extra":{}}@*&#$')
                     return None
                 self._queue.pop(0)
 
@@ -96,7 +96,7 @@ class SerialPort():
         except serial.serialutil.SerialException as e:
             self.exiting = True
             print("\033[1;33m连接失败，未检测到设备\033[0m")
-            print('$#&*@{"err_code":102,"err_msg":"未检测到设备","device":"mkpiano","extra":{}}@*&#$')
+            print('$#&*@{"err_code":102,"err_msg":"读取数据失败，未检测到设备","device":"mkpiano","extra":{}}@*&#$')
             return []
 
     def enable_sending(self):
